Theme

Struct Theme 

pub struct Theme {
    pub primary: Color,
    pub secondary: Color,
    pub background: Color,
    pub surface: Color,
    pub border: Color,
    pub foreground: Color,
    pub muted: Color,
    pub success: Color,
    pub warning: Color,
    pub error: Color,
}
Represents generated theme containing different colors.

It is used to generated a theme from the given color and then contain the generated colors.

Example

use gecol_core::theme::Theme;

// Generates dark theme
let theme = Theme::dark((155, 155, 0));

Fields

primary: Colorsecondary: Colorbackground: Colorsurface: Colorborder: Colorforeground: Colormuted: Colorsuccess: Colorwarning: Colorerror: Color

Implementations

Source

impl Theme

pub fn generate(theme_type: ThemeType, rgb: (u8, u8, u8)) -> Self

Generates the theme based on the given color..

It generates based on the given theme type. The given color will be the primary color and the other colors willbe generated based on that color.

pub fn dark((r, g, b): (u8, u8, u8)) -> Self

Generates dark theme based on the given color.

Given color will be the primary color and the other colors will be generated based on that color.

pub fn light((r, g, b): (u8, u8, u8)) -> Self

Generates light theme based on the given color.

Given color will be the primary color and the other colors will be generated based on that color. It restrains the maximum primary color lightness in order for it to be visible.