pub struct Extractor<'a> { /* private fields */ }Expand description
A utility for extracting accent color from an image.
This structs acts as a temporary state container during the extraction process and provides static methods for executing the extraction.
There are multiple extraction variants, mainly with
(Extractor::extract) and without (Extractor::extract_cached) using
the Cache. It is highly recommended using the Cache. High
resolution images can take a while to just open, so thanks to the Cache
the result for repeated extraction will be pretty much instant.
You can also use variant with progress reporting
(Extractor::extract_with_progress and
Extractor::extract_cached_with_progress), which is useful for having
a loading screen, for example.
Implementations
Sourceimpl<'a> Extractor<'a>
impl<'a> Extractor<'a>
Sourcepub fn extract<P>(
path: P,
config: &'a ExtractionConfig,
) -> Result<Option<(u8, u8, u8)>, Error>
pub fn extract<P>( path: P, config: &'a ExtractionConfig, ) -> Result<Option<(u8, u8, u8)>, Error>
Extracts the accent color from the image at the given path.
When no sufficient color is found, it returns None.
Sourcepub fn extract_cached<P>(
path: P,
config: &'a ExtractionConfig,
cache_path: Option<&Path>,
) -> Result<Option<(u8, u8, u8)>, Error>
pub fn extract_cached<P>( path: P, config: &'a ExtractionConfig, cache_path: Option<&Path>, ) -> Result<Option<(u8, u8, u8)>, Error>
Extracts the accent color from the image at the given path and uses the cache.
It checks if the cache already contains the color for the given image, otherwise it saves the extracted color into the cache.
When no sufficient color is found, it returns None.
Sourcepub fn extract_with_progress<P, F>(
path: P,
config: &'a ExtractionConfig,
progress_callback: F,
) -> Result<Option<(u8, u8, u8)>, Error>
pub fn extract_with_progress<P, F>( path: P, config: &'a ExtractionConfig, progress_callback: F, ) -> Result<Option<(u8, u8, u8)>, Error>
Extracts the accent color from the image at the given path with the progress reporting.
When no sufficient color is found, it returns None.
Sourcepub fn extract_cached_with_progress<P, F>(
path: P,
config: &'a ExtractionConfig,
cache_path: Option<&Path>,
progress_callback: F,
) -> Result<Option<(u8, u8, u8)>, Error>
pub fn extract_cached_with_progress<P, F>( path: P, config: &'a ExtractionConfig, cache_path: Option<&Path>, progress_callback: F, ) -> Result<Option<(u8, u8, u8)>, Error>
Extracts the accent color from the image at the given path with the progress reporting and uses the cache.
It checks if the cache already contains the color for the given image, otherwise it saves the extracted color into the cache.
When no sufficient color is found, it returns None.