pub struct Cache {
pub entries: HashMap<String, (u8, u8, u8)>,
}Expand description
Allows caching extraction results.
Using cache improves performance a lot, so it is recommended to use. First time you extract color from the image, it can take a bit longer, since just opening a high resolution image takes a bit of time. To improve this, the extracted color is stored in the cache (when used), so the next time you want to extract color from the same image, it is pretty much instant.
Usage
Generaly you don’t need to use the cache directly, you can use the specific
Extractor methods:
Fields
entries: HashMap<String, (u8, u8, u8)>Implementations
Sourceimpl Cache
impl Cache
Sourcepub fn load_default() -> Self
pub fn load_default() -> Self
Loads the cache from the default cache file path.
Default cache file path is given by the Cache::file.
If it fails to load or find the cache file, it returns default cache.
Sourcepub fn load<P>(file: P) -> Self
pub fn load<P>(file: P) -> Self
Loads the cache from the given file path.
If it fails to load or find the cache file, it returns default cache.
Sourcepub fn save_default(&self) -> Result<(), Error>
pub fn save_default(&self) -> Result<(), Error>
Saves the current cache to the default cache file path.
Default cache file path is given by the Cache::file.
Sourcepub fn save<P>(&self, file: P) -> Result<(), Error>
pub fn save<P>(&self, file: P) -> Result<(), Error>
Saves the current cache to the given file path.
Sourcepub fn key<P>(config: &ExtractionConfig, image: P) -> Result<String, Error>
pub fn key<P>(config: &ExtractionConfig, image: P) -> Result<String, Error>
Generates the cache key for the given config and image.
This is done so that any change in config, that would effect the extracted color, is detected. It also can detect the image being modified.
Sourcepub fn file() -> PathBuf
pub fn file() -> PathBuf
Gets the default cache file path.
It uses the Cache::dir to get the cache directory, followed by the
colors.bin.