pub struct Theme {
pub primary: Color,
pub secondary: Color,
pub background: Color,
pub surface: Color,
pub border: Color,
pub foreground: Color,
pub muted: Color,
pub success: Color,
pub warning: Color,
pub error: Color,
}Expand description
Represents generated theme containing different colors.
It is used to generated a theme from the given color and then contain the generated colors.
Example
use gecol_core::theme::Theme;
// Generates dark theme
let theme = Theme::dark((155, 155, 0));Fields
primary: Colorsecondary: Colorbackground: Colorsurface: Colorborder: Colorforeground: Colormuted: Colorsuccess: Colorwarning: Colorerror: ColorImplementations
Sourceimpl Theme
impl Theme
Sourcepub fn generate(theme_type: ThemeType, rgb: (u8, u8, u8)) -> Self
pub fn generate(theme_type: ThemeType, rgb: (u8, u8, u8)) -> Self
Generates the theme based on the given color..
It generates based on the given theme type. The given color will be the primary color and the other colors willbe generated based on that color.